@@ -12,11 +12,13 @@ from __future__ import unicode_literals
 #: correct parsing of the last name "von bergen wessels".
 PREFIXES = set([
     'abu',
+    'al',
     'bin',
     'bon',
     'da',
     'dal',
     'de',
+    'de\'',
     'degli',
     'dei',
     'del',
@@ -34,11 +36,15 @@ PREFIXES = set([
     'ibn',
     'la',
     'le',
+    'mac',
+    'mc',
     'san',
     'santa',
     'st',
     'ste',
     'van',
+    'vander',
     'vel',
     'von',
+    'vom',
 ])
