@@ -2071,6 +2071,11 @@ class TitleTestCase(HumanNameTestBase):
         self.m(hn.first, "Mike", hn)
         self.m(hn.last, "van der Velt", hn)
 
+    def test_2_same_prefixes_in_the_name(self):
+        hh = HumanName("Vincent van Gogh van Beethoven")
+        self.m(hh.first, "Vincent", hh)
+        self.m(hh.middle, "van Gogh", hh)
+        self.m(hh.last, "van Beethoven", hh)
 
 class HumanNameCapitalizationTestCase(HumanNameTestBase):
     def test_capitalization_exception_for_III(self):
@@ -2343,12 +2348,12 @@ class InitialsTestCase(HumanNameTestBase):
     def test_initials_with_prefix(self):
         hn = HumanName("Alex van Johnson")
         self.m(hn.initials_list(), ["A", "J"], hn)
-        
+
     def test_constructor_first(self):
         hn = HumanName(first="TheName")
         self.assertFalse(hn.unparsable)
         self.m(hn.first, "TheName", hn)
-    
+
     def test_constructor_middle(self):
         hn = HumanName(middle="TheName")
         self.assertFalse(hn.unparsable)
@@ -2380,7 +2385,7 @@ class InitialsTestCase(HumanNameTestBase):
         self.m(hn.first, "TheName", hn)
         self.m(hn.last, "lastname", hn)
         self.m(hn.title, "mytitle", hn)
-    
+
 
 TEST_NAMES = (
     "John Doe",
